// java wrapper for vtkTextPropertyCollection object
//

package vtk;
import vtk.*;

public class vtkTextPropertyCollection extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddItem_2(vtkTextProperty id0);
  public void AddItem(vtkTextProperty id0)
    { AddItem_2(id0); }

  private native long GetNextItem_3();
  public vtkTextProperty GetNextItem() {
    long temp = GetNextItem_3();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetItem_4(int id0);
  public vtkTextProperty GetItem(int id0) {
    long temp = GetItem_4(id0);

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLastItem_5();
  public vtkTextProperty GetLastItem() {
    long temp = GetLastItem_5();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTextPropertyCollection() { super(); }

  public vtkTextPropertyCollection(long id) { super(id); }
  public native long   VTKInit();

}
